function [ u ] = fbaccala2016_example1( ns, nDiscard, flgRandomize )
%FBACCALA2016_EXAMPLE1 Linear bivariate VAR[2] without feedback model
% From:
% Luiz A. Baccala; Daniel Y. Takahashi; Koichi Sameshima.Directed Transfer 
% Function: Unified Asymptotic Theory and Some of its Implications. 
% _IEEE Transactions on Biomedical Engineering_ *PP*, 2016.
%
% <http://dx.doi.org/10.1109/TBME.2016.2550199>

if ~flgRandomize,
   disp(' ')
   disp('======================================================================');
   disp('      "DTF Unified Asymptotic Theory" Simple Example 1, ns =50 ');
   disp('                 x1 ==> x2');
   disp('======================================================================');
end;
if (nargin == 0),
   ns = 50;
   nDiscard = 2000;
   disp(['Adopting default ' int2str(nDiscard) ' discarding points, and'])
   disp(['generating ' int2str(ns) ' simulation data point.'])
   
elseif   (nargin < 2),
   nDiscard = 2000;
   disp(['Adopting default ' int2str(nDiscard) ' discarding points.'])
end;

if (nDiscard < 1),
   nDiscard = 5000;
   disp(['Adopting default ' int2str(nDiscard) ' discarding points.'])
end;

if ns < 10,
   ns = 500;
   disp(['Adopting default ' int2str(ns) ' simulation data points.'])
end;

% If flgRandomize == 0, it generate the data set used in Figure 1

if flgRandomize,
   randn('state', sum(100*clock))
else
   randn('state',2.095318000000000e+005)
end;

p = 2;            % model order 

N=nDiscard + ns + p; % Number of data points to be generated.
%%
% Variables initialization
ei=randn(2,N); x1=zeros(1,N); x2=zeros(1,N);

for t=1:2,
   x1(t)=randn(1); x2(t)=randn(1);
end;

for t=3:N,
   x1(t)= 2*0.95*cos(pi/4)*x1(t-1)-(.95)^2*x1(t-2) + ei(1,t);
   x2(t) = 0.50*x1(t-1) - 0.5*x2(t-1) + ei(2,t);
end;

y = [x1' x2']; % data must be organized column-wise
u = y(nDiscard+1:nDiscard+ns,:)';

end

