function [ u ] = fbaccala2016_example2( ns, nDiscard, flgRandomize )
%FBACCALA2016_EXAMPLE2 Linear trivariate VAR[2] loop model
% From:
% Luiz A. Baccala; Daniel Y. Takahashi; Koichi Sameshima.Directed Transfer 
% Function: Unified Asymptotic Theory and Some of its Implications. 
% _IEEE Transactions on Biomedical Engineering_ *PP*, 2016.
%
% <http://dx.doi.org/10.1109/TBME.2016.2550199>

if ~flgRandomize,
   disp(' ')
   disp('======================================================================');
   disp('           "DTF Unified Asymptotic Theory" Example 2');
   disp('                      x1 ==> x2 ==> x3');
   disp('                       ^-----------/');
   disp('======================================================================');
end;

if (nargin == 0),
   ns = 500;
   nDiscard = 20000;
   disp(['Adopting default ' int2str(nDiscard) ' discarding points, and'])
   disp(['generating ' int2str(ns) ' simulation data point.'])
   
elseif   (nargin < 2),
   nDiscard = 20000;
   disp(['Adopting default ' int2str(nDiscard) ' discarding points.'])
end;

if (nDiscard < 1),
   nDiscard = 20000;
   disp(['Adopting default ' int2str(nDiscard) ' discarding points.'])
end;

if ns < 10,
   ns = 500;
   disp(['Adopting default ' int2str(ns) ' simulation data points.'])
end;

% If flgRandomize == 0, it generate the data set used in Figure 1
p = 1;
if flgRandomize,
   randn('state', sum(100*clock))
else
   randn('state',2.095318000000000e+004)
end;

N = ns + nDiscard + p;
% Variables initialization
x1=zeros(1,N); x2=zeros(1,N);x3=zeros(1,N);
SZ=[1 5 0.30; 5 100 2; 0.30 2 1];SZ=chol(SZ); 
ei=randn(3,N);
ei=SZ'*ei;

for n=1:2,
   x1(n)=randn(1); x2(n)=randn(1);x3(n)=randn(1);
end;

for n=3:N,
   x1(n) = 2*0.95*cos(pi/4)*x1(n-1) - 0.9025*x1(n-2) + 0.35*x3(n-1)+ ei(1,n);
   x2(n) = 0.5*x1(n-1) + 0.5*x2(n-1) + ei(2,n);
   x3(n) = x2(n-1) - 0.5*x3(n-1) + ei(3,n);
end;

y = [x1' x2' x3']; % data must be organized column-wise
u = y(nDiscard+1:nDiscard+ns,:)';

end
