function [ u ] = fbaccala2016_example3( ns, nDiscard, flgRandomize )
%FBACCALA2016_EXAMPLE3 Linear 5-dimensional VAR[2] model
% From:
% Luiz A. Baccala; Daniel Y. Takahashi; Koichi Sameshima.Directed Transfer 
% Function: Unified Asymptotic Theory and Some of its Implications. 
% _IEEE Transactions on Biomedical Engineering_ *PP*, 2016.
%
% <http://dx.doi.org/10.1109/TBME.2016.2550199>

if ~flgRandomize,
   disp(' ')
   disp('======================================================================');
   disp('   Asymptotic DTF:  Example 3 5-VAR model - open / closed loop.');
   disp('                 x1 ==> x2 ==> x3 ==> x4 <==> x5');
   disp('                  ^--------------------------/');
   disp('                   This is the close loop model.');
   disp('======================================================================');
end;

kLoop = 1; % 0: 'open'; 1: 'closed'

if (nargin == 0),
   ns = 2000;
   nDiscard = 20000;
   disp(['Adopting default ' int2str(nDiscard) ' discarding points, and'])
   disp(['generating ' int2str(ns) ' simulation data point.'])
   
elseif   (nargin < 2),
   nDiscard = 20000;
   disp(['Adopting default ' int2str(nDiscard) ' discarding points.'])
end;

if (nDiscard < 1),
   nDiscard = 20000;
   disp(['Adopting default ' int2str(nDiscard) ' discarding points.'])
end;

if ns < 10,
   ns = 2000;
   disp(['Adopting default ' int2str(ns) ' simulation data points.'])
end;

% If flgRandomize == 0, it generate the data set used in Figure 1
p = 1;
if flgRandomize,
   randn('state', sum(100*clock))
else
   randn('state',2.095318000000000e+004)
end;

N = ns + nDiscard + p;
% Variables initialization
wi=randn(5,N);
x1 = zeros(1,N); x2 = zeros(1,N); x3 = zeros(1,N); x4 = zeros(1,N);
x5 = zeros(1,N);
for t=1:4,
   x1(t)=randn(1); x2(t)=randn(1); x3(t)=randn(1); x4(t)=randn(1);
   x5(t)=randn(1);
end;

for t=5:N,
   x1(t) = 0.95*sqrt(2)*x1(t-1) - 0.9025*x1(t-2) + kLoop * 0.5*x5(t-2)+ wi(1,t);
   x2(t) = -0.5*x1(t-1) + wi(2,t);
   x3(t) = 0.4*x2(t-2) + wi(3,t);
   x4(t) = -0.5*x3(t-1) + 0.25*sqrt(2)*x4(t-1) + 0.25*sqrt(2)*x5(t-1) + wi(4,t);
   x5(t) = -0.25*sqrt(2)*x4(t-1) + 0.25*sqrt(2)*x5(t-1) + wi(5,t);
end;

y=[x1' x2' x3' x4' x5']; % data must be organized column-wise

u=y(nDiscard+1:nDiscard+ns,:)';

end
