function [ u ] = fbaccala2016_example4( ns, nDiscard, flgRandomize )
%FBACCALA2016_EXAMPLE4 Linear trivariate reachability VAR[2] model
% From:
% Luiz A. Baccala; Daniel Y. Takahashi; Koichi Sameshima.Directed Transfer 
% Function: Unified Asymptotic Theory and Some of its Implications. 
% _IEEE Transactions on Biomedical Engineering_ *PP*, 2016.
%
% <http://dx.doi.org/10.1109/TBME.2016.2550199>

if ~flgRandomize,
   disp(' ')
   disp('======================================================================');
   disp(['     "Asymptotic DTF" Reachability Example 4, ns = ' int2str(ns)]);
   disp('                 x1 <==> x2 -->x3');
   disp('======================================================================');
end;

if (nargin == 0),
   ns = 50;
   nDiscard = 2000;
   disp(['Adopting default ' int2str(nDiscard) ' discarding points, and'])
   disp(['generating ' int2str(ns) ' simulation data point.'])
   
elseif   (nargin < 2),
   nDiscard = 2000;
   disp(['Adopting default ' int2str(nDiscard) ' discarding points.'])
end;

if (nDiscard < 1),
   nDiscard = 2000;
   disp(['Adopting default ' int2str(nDiscard) ' discarding points.'])
end;

if ns < 10,
   ns = 50;
   disp(['Adopting default ' int2str(ns) ' simulation data points.'])
end;

% If flgRandomize == 0, it generate the data set used in Figure 1
p = 2;
if flgRandomize,
   randn('state', sum(100*clock))
else
   randn('state',2.095318000000000e+005)
end;

N = ns + nDiscard + p;
% Variables initialization
wi = randn(3,N);
x1 = zeros(1,N);
x2 = zeros(1,N);
x3 = zeros(1,N);
for t=1:4,
   x1(t) = randn(1); x2(t) = randn(1); x3(t) = randn(1);
end;

for t=2:N,
   x1(t) = 0.25*sqrt(2)*x1(t-1) + 0.25*sqrt(2)*x2(t-1) + wi(1,t);
   x2(t) = -0.25*sqrt(2)*x1(t-1) + 0.25*sqrt(2)*x2(t-1) + wi(2,t);
   x3(t) = 0.5*x2(t-1) + wi(3,t);
end;

y=[x1' x2' x3']; % data must be organized column-wise

u = y(nDiscard+1:nDiscard+ns,:)';

end
