%% DTF_IEEE_2016 Routines
%
%  These routines and data files are supplements for the article
%
% LA Baccala, DY Takahashi, K Sameshima (2016) Directed Transfer 
% Function: Unified Asymptotic Theory and Some of its Implications. 
% _IEEE Transactions on Biomedical Engineering_ *PP*.
%
% <http://dx.doi.org/10.1109/TBME.2016.2550199> 
% 
% DESCRIPTION:
%
% The Asymp_PDC_v3 package is required to run the routines. This package
% is availabe at http://www.lcs.poli.usp.br/~baccala/pdc/dtf.html. The
% package and the generation of figures for the articles have been tested
% in Matlab, as well as in Octave versions 4.0.0 and 4.0.3, for Windows, 
% Mac OSX and Ubuntu 14.04 and 16.04. Two important differences between Matlab
% and Octave relevant for the figures generation of the
% article are in the sequence of pseudorandom numbers generation by randn and
% in the behavior of at least one supporting routine, sublabel.m function.  
% To troubleshot whenever we observed a difference of behavior in Octave, 
% the is_octave function was used.
% 
% In order to reproduce exactly the same results on DTF and PDC estimates, 
% i.e. Figures 1, 2, 5, 6, 9 and 11, we have provide sample 
% data files that are automatically loaded when Octave is used.
%
% For Monte Carlo simulations of Figures 3, 7 and 12, the results will
% vary per simulation basis.
%
% This set of routines and auxiliary files contains the following:
%
%    [./DTFIEEE]
%       a) M-files, figure#*.m, to generate the 9 figures in the article 
%             figure1_example1_pdc_dtf_ns50.m               
%             figure1_example1_pdc_dtf_ns50_tst.m           
%             figure2_example1_pdc_dtf_ns500.m         
%             figure3_example1_dtf_qqplots_ns50_500.m       
%             figure5_example2_ipdc_idtf_ns500.m
%             figure6_example2_ipdc_idtf_ns2000.m           
%             figure7_example2_idtf_qqplots_ns500_2000.m    
%             figure9_example3_idtf_ns2000.m         
%             figure11_example4_dtf_ns50_500.m              
%             figure12_example4_dtf_qqplots_ns50_500.m      
%
%       b) Data sample generating functions for examples 1 to 4, fbaccala16_example#.m used to
%       generate data sample:
%             fbaccala2016_example1.m                       
%             fbaccala2016_example2.m                       
%             fbaccala2016_example3.m                       
%             fbaccala2016_example4.m                       
%
%       c) Data samples, mat-files, used to generate the figures.
%             figure1_example1_pdc_dtf_ns50.mat          
%             figure2_example1_pdc_dtf_ns500.mat     
%             figure5_example2_ipdc_idtf_ns500.mat       
%             figure6_example2_ipdc_idtf_ns2000.mat
%             figure9_example3_idtf_ns2000.mat
%             figure11_example4_dtf_ns50.mat       
%             figure11_example4_dtf_ns500.mat
%
%          Mat-files generated in Matlab environment that are used in
%          Octave environment.
%
%          In the simulations the initial state of pseudorandom number
%          generator was set by
%                randn('state',2.095318000000000e+005); % Examples 1 and 4
%          or
%                randn('state',2.095318000000000e+004); % Examples 2 and 3,  
%          which gives the results shown in the articles, as the randn
%          consistently generate same sequence of pseudo random numbers
%          regardless of the version (it seems) or the operating system (we
%          tested in limited combination on Mac OSX, Windows and Linux 
%          MATLAB environment) used.
%
%       d) Batch m-file that runs all routines listed in a)
%             run_figures.m
%
%       e) XSL files to be used to be used in output setting together
%          with latex option of "publish" in Matlab
%              matlab2latex-pretty.xsl
%              matlab2latex-pretty2.xsl
%
%   [./DTFIEEE/html]
%       f) This folder or directory contains auxiliary files used for 
%          publishing task.
%       g) Publish report files in pdf-format:
%             figure1_example1_pdc_dtf_ns50.pdf               
%             figure1_example1_pdc_dtf_ns50_tst.pdf           
%             figure2_example1_pdc_dtf_ns500.pdf         
%             figure3_example1_dtf_qqplots_ns50_500.pdf       
%             figure5_example2_ipdc_idtf_ns500.pdf
%             figure6_example2_ipdc_idtf_ns2000.pdf           
%             figure7_example2_idtf_qqplots_ns500_2000.pdf    
%             figure9_example3_idtf_ns2000.pdf         
%             figure11_example4_dtf_ns50_500.pdf              
%             figure12_example4_dtf_qqplots_ns50_500.pdf      
%
%             These publish pdf-files were generated using publish withe the
%             corresponding routine m-files and matlab2latex-pretty2.xsl
%             file, then compiled with LDFLaTeX compiler with
%             `matlab-prettifier.sty' by by Julien Cretel
%             <jubobs.matlab.prettifier at gmail.com>.
%
%          If have spotted a bug, or have comments and criticisms we will 
%          appreciate any feedback. Our email addresses:
%                        baccala[at]lcs[dot]poli[dot]usp[dot]br or
%                        ksameshi[at]usp[dot]usp


    